==> lightning-2.1.1.tar.gz: lightning-2.1.1/lib/jit_ia64-sz.c <==

#if __WORDSIZE == 64
#define JIT_INSTR_MAX 224
    0,	/* data */
    0,	/* live */
    0,	/* align */
    0,	/* save */
    0,	/* load */
    0,	/* #name */
    0,	/* #note */
    0,	/* label */
    224,	/* prolog */
    0,	/* ellipsis */
    0,	/* allocai */
    0,	/* allocar */
    0,	/* arg */
    0,	/* getarg_c */
    0,	/* getarg_uc */
    0,	/* getarg_s */
    0,	/* getarg_us */
    0,	/* getarg_i */
    0,	/* getarg_ui */
    0,	/* getarg_l */
    0,	/* putargr */
    0,	/* putargi */
    16,	/* va_start */
    32,	/* va_arg */
    32,	/* va_arg_d */
    0,	/* va_end */
    16,	/* addr */
    32,	/* addi */
    32,	/* addcr */
    48,	/* addci */
    64,	/* addxr */
    64,	/* addxi */
    16,	/* subr */
    32,	/* subi */
    32,	/* subcr */
    48,	/* subci */
    64,	/* subxr */
    64,	/* subxi */
    32,	/* rsbi */
    48,	/* mulr */
    64,	/* muli */
    112,	/* qmulr */
    112,	/* qmuli */
    112,	/* qmulr_u */
    112,	/* qmuli_u */
    80,	/* divr */
    96,	/* divi */
    80,	/* divr_u */
    96,	/* divi_u */
    144,	/* qdivr */
    144,	/* qdivi */
    144,	/* qdivr_u */
    144,	/* qdivi_u */
    80,	/* remr */
    96,	/* remi */
    80,	/* remr_u */
    96,	/* remi_u */
    16,	/* andr */
    32,	/* andi */
    16,	/* orr */
    32,	/* ori */
    16,	/* xorr */
    32,	/* xori */
    16,	/* lshr */
    16,	/* lshi */
    16,	/* rshr */
    16,	/* rshi */
    16,	/* rshr_u */
    16,	/* rshi_u */
    16,	/* negr */
    16,	/* comr */
    32,	/* ltr */
    32,	/* lti */
    32,	/* ltr_u */
    32,	/* lti_u */
    32,	/* ler */
    32,	/* lei */
    32,	/* ler_u */
    32,	/* lei_u */
    32,	/* eqr */
    32,	/* eqi */
    32,	/* ger */
    32,	/* gei */
    32,	/* ger_u */
    32,	/* gei_u */
    32,	/* gtr */
    32,	/* gti */
    32,	/* gtr_u */
    32,	/* gti_u */
    32,	/* ner */
    32,	/* nei */
    16,	/* movr */
    16,	/* movi */
    16,	/* extr_c */
    16,	/* extr_uc */
    16,	/* extr_s */
    16,	/* extr_us */
    16,	/* extr_i */
    16,	/* extr_ui */
    64,	/* htonr_us */
    160,	/* htonr_ui */
    16,	/* htonr_ul */
    16,	/* ldr_c */
    32,	/* ldi_c */
    16,	/* ldr_uc */
    32,	/* ldi_uc */
    16,	/* ldr_s */
    32,	/* ldi_s */
    16,	/* ldr_us */
    32,	/* ldi_us */
    16,	/* ldr_i */
    32,	/* ldi_i */
    16,	/* ldr_ui */
    32,	/* ldi_ui */
    16,	/* ldr_l */
    32,	/* ldi_l */
    32,	/* ldxr_c */
    48,	/* ldxi_c */
    16,	/* ldxr_uc */
    32,	/* ldxi_uc */
    32,	/* ldxr_s */
    48,	/* ldxi_s */
    16,	/* ldxr_us */
    32,	/* ldxi_us */
    32,	/* ldxr_i */
    48,	/* ldxi_i */
    16,	/* ldxr_ui */
    32,	/* ldxi_ui */
    16,	/* ldxr_l */
    32,	/* ldxi_l */
    16,	/* str_c */
    32,	/* sti_c */
    16,	/* str_s */
    32,	/* sti_s */
    16,	/* str_i */
    32,	/* sti_i */
    16,	/* str_l */
    32,	/* sti_l */
    16,	/* stxr_c */
    32,	/* stxi_c */
    16,	/* stxr_s */
    32,	/* stxi_s */
    16,	/* stxr_i */
    32,	/* stxi_i */
    16,	/* stxr_l */
    32,	/* stxi_l */
    32,	/* bltr */
    32,	/* blti */
    32,	/* bltr_u */
    32,	/* blti_u */
    32,	/* bler */
    32,	/* blei */
    32,	/* bler_u */
    32,	/* blei_u */
    32,	/* beqr */
    48,	/* beqi */
    32,	/* bger */
    32,	/* bgei */
    32,	/* bger_u */
    32,	/* bgei_u */
    32,	/* bgtr */
    32,	/* bgti */
    32,	/* bgtr_u */
    32,	/* bgti_u */
    32,	/* bner */
    48,	/* bnei */
    32,	/* bmsr */
    48,	/* bmsi */
    32,	/* bmcr */
    48,	/* bmci */
    96,	/* boaddr */
    112,	/* boaddi */
    64,	/* boaddr_u */
    64,	/* boaddi_u */
    96,	/* bxaddr */
    112,	/* bxaddi */
    64,	/* bxaddr_u */
    64,	/* bxaddi_u */
    112,	/* bosubr */
    112,	/* bosubi */
    64,	/* bosubr_u */
    64,	/* bosubi_u */
    112,	/* bxsubr */
    112,	/* bxsubi */
    64,	/* bxsubr_u */
    64,	/* bxsubi_u */
    16,	/* jmpr */
    16,	/* jmpi */
    32,	/* callr */
    48,	/* calli */
    0,	/* prepare */
    0,	/* pushargr */
    0,	/* pushargi */
    0,	/* finishr */
    0,	/* finishi */
    0,	/* ret */
    0,	/* retr */
    0,	/* reti */
    0,	/* retval_c */
    0,	/* retval_uc */
    0,	/* retval_s */
    0,	/* retval_us */
    0,	/* retval_i */
    0,	/* retval_ui */
    0,	/* retval_l */
    128,	/* epilog */
    0,	/* arg_f */
    0,	/* getarg_f */
    0,	/* putargr_f */
    0,	/* putargi_f */
    16,	/* addr_f */
    48,	/* addi_f */
    16,	/* subr_f */
    48,	/* subi_f */
    48,	/* rsbi_f */
    16,	/* mulr_f */
    48,	/* muli_f */
    160,	/* divr_f */
    192,	/* divi_f */
    16,	/* negr_f */
    16,	/* absr_f */
    80,	/* sqrtr_f */
    32,	/* ltr_f */
    64,	/* lti_f */
    32,	/* ler_f */
    64,	/* lei_f */
    32,	/* eqr_f */
    64,	/* eqi_f */
    32,	/* ger_f */
    64,	/* gei_f */
    32,	/* gtr_f */
    64,	/* gti_f */
    32,	/* ner_f */
    64,	/* nei_f */
    32,	/* unltr_f */
    64,	/* unlti_f */
    32,	/* unler_f */
    64,	/* unlei_f */
    48,	/* uneqr_f */
    96,	/* uneqi_f */
    32,	/* unger_f */
    64,	/* ungei_f */
    32,	/* ungtr_f */
    64,	/* ungti_f */
    48,	/* ltgtr_f */
    96,	/* ltgti_f */
    32,	/* ordr_f */
    64,	/* ordi_f */
    32,	/* unordr_f */
    64,	/* unordi_f */
    32,	/* truncr_f_i */
    32,	/* truncr_f_l */
    48,	/* extr_f */
    16,	/* extr_d_f */
    16,	/* movr_f */
    32,	/* movi_f */
    16,	/* ldr_f */
    32,	/* ldi_f */
    16,	/* ldxr_f */
    32,	/* ldxi_f */
    16,	/* str_f */
    32,	/* sti_f */
    16,	/* stxr_f */
    32,	/* stxi_f */
    32,	/* bltr_f */
    64,	/* blti_f */
    32,	/* bler_f */
    64,	/* blei_f */
    32,	/* beqr_f */
    64,	/* beqi_f */
    32,	/* bger_f */
    64,	/* bgei_f */
    32,	/* bgtr_f */
    64,	/* bgti_f */
    32,	/* bner_f */
    64,	/* bnei_f */
    32,	/* bunltr_f */
    64,	/* bunlti_f */
    32,	/* bunler_f */
    64,	/* bunlei_f */
    80,	/* buneqr_f */
    112,	/* buneqi_f */
    32,	/* bunger_f */
    64,	/* bungei_f */
    32,	/* bungtr_f */
    64,	/* bungti_f */
    80,	/* bltgtr_f */
    112,	/* bltgti_f */
    32,	/* bordr_f */
    64,	/* bordi_f */
    32,	/* bunordr_f */
    64,	/* bunordi_f */
    0,	/* pushargr_f */
    0,	/* pushargi_f */
    0,	/* retr_f */
    0,	/* reti_f */
    0,	/* retval_f */
    0,	/* arg_d */
    0,	/* getarg_d */
    0,	/* putargr_d */
    0,	/* putargi_d */
    16,	/* addr_d */
    48,	/* addi_d */
    16,	/* subr_d */
    48,	/* subi_d */
    48,	/* rsbi_d */
    16,	/* mulr_d */
    48,	/* muli_d */
    160,	/* divr_d */
    192,	/* divi_d */
    16,	/* negr_d */
    16,	/* absr_d */
    80,	/* sqrtr_d */
    32,	/* ltr_d */
    64,	/* lti_d */
    32,	/* ler_d */
    64,	/* lei_d */
    32,	/* eqr_d */
    64,	/* eqi_d */
    32,	/* ger_d */
    64,	/* gei_d */
    32,	/* gtr_d */
    64,	/* gti_d */
    32,	/* ner_d */
    64,	/* nei_d */
    32,	/* unltr_d */
    64,	/* unlti_d */
    32,	/* unler_d */
    64,	/* unlei_d */
    48,	/* uneqr_d */
    96,	/* uneqi_d */
    32,	/* unger_d */
    64,	/* ungei_d */
    32,	/* ungtr_d */
    64,	/* ungti_d */
    48,	/* ltgtr_d */
    96,	/* ltgti_d */
    32,	/* ordr_d */
    64,	/* ordi_d */
    32,	/* unordr_d */
    64,	/* unordi_d */
    32,	/* truncr_d_i */
    32,	/* truncr_d_l */
    48,	/* extr_d */
    16,	/* extr_f_d */
    16,	/* movr_d */
    32,	/* movi_d */
    16,	/* ldr_d */
    32,	/* ldi_d */
    16,	/* ldxr_d */
    32,	/* ldxi_d */
    16,	/* str_d */
    32,	/* sti_d */
    16,	/* stxr_d */
    32,	/* stxi_d */
    32,	/* bltr_d */
    64,	/* blti_d */
    32,	/* bler_d */
    64,	/* blei_d */
    32,	/* beqr_d */
    64,	/* beqi_d */
    32,	/* bger_d */
    64,	/* bgei_d */
    32,	/* bgtr_d */
    64,	/* bgti_d */
    32,	/* bner_d */
    64,	/* bnei_d */
    32,	/* bunltr_d */
    64,	/* bunlti_d */
    32,	/* bunler_d */
    64,	/* bunlei_d */
    80,	/* buneqr_d */
    112,	/* buneqi_d */
    32,	/* bunger_d */
    64,	/* bungei_d */
    32,	/* bungtr_d */
    64,	/* bungti_d */
    80,	/* bltgtr_d */
    112,	/* bltgti_d */
    32,	/* bordr_d */
    64,	/* bordi_d */
    32,	/* bunordr_d */
    64,	/* bunordi_d */
    0,	/* pushargr_d */
    0,	/* pushargi_d */
    0,	/* retr_d */
    0,	/* reti_d */
    0,	/* retval_d */
    0,	/* movr_w_f */
    0,	/* movr_ww_d */
    0,	/* movr_w_d */
    0,	/* movr_f_w */
    0,	/* movi_f_w */
    0,	/* movr_d_ww */
    0,	/* movi_d_ww */
    16,	/* movr_d_w */
    32,	/* movi_d_w */
#endif /* __WORDSIZE */

==> lightning-2.1.4.tar.gz: lightning-2.1.4/lib/jit_ia64-sz.c <==
#if __WORDSIZE == 64
#define JIT_INSTR_MAX 224
    0,	/* data */
    0,	/* live */
    0,	/* align */
    0,	/* save */
    0,	/* load */
    0,  /* skip */
    0,	/* #name */
    0,	/* #note */
    0,	/* label */
    224,	/* prolog */
    0,	/* ellipsis */
    0,	/* va_push */
    0,	/* allocai */
    0,	/* allocar */
    0,	/* arg */
    0,	/* getarg_c */
    0,	/* getarg_uc */
    0,	/* getarg_s */
    0,	/* getarg_us */
    0,	/* getarg_i */
    0,	/* getarg_ui */
    0,	/* getarg_l */
    0,	/* putargr */
    0,	/* putargi */
    16,	/* va_start */
    32,	/* va_arg */
    32,	/* va_arg_d */
    0,	/* va_end */
    16,	/* addr */
    32,	/* addi */
    32,	/* addcr */
    48,	/* addci */
    64,	/* addxr */
    64,	/* addxi */
    16,	/* subr */
    32,	/* subi */
    32,	/* subcr */
    48,	/* subci */
    64,	/* subxr */
    64,	/* subxi */
    32,	/* rsbi */
    48,	/* mulr */
    64,	/* muli */
    112,	/* qmulr */
    112,	/* qmuli */
    112,	/* qmulr_u */
    112,	/* qmuli_u */
    80,	/* divr */
    96,	/* divi */
    80,	/* divr_u */
    96,	/* divi_u */
    144,	/* qdivr */
    144,	/* qdivi */
    144,	/* qdivr_u */
    144,	/* qdivi_u */
    80,	/* remr */
    96,	/* remi */
    80,	/* remr_u */
    96,	/* remi_u */
    16,	/* andr */
    32,	/* andi */
    16,	/* orr */
    32,	/* ori */
    16,	/* xorr */
    32,	/* xori */
    16,	/* lshr */
    16,	/* lshi */
    16,	/* rshr */
    16,	/* rshi */
    16,	/* rshr_u */
    16,	/* rshi_u */
    16,	/* negr */
    16,	/* comr */
    32,	/* ltr */
    32,	/* lti */
    32,	/* ltr_u */
    32,	/* lti_u */
    32,	/* ler */
    32,	/* lei */
    32,	/* ler_u */
    32,	/* lei_u */
    32,	/* eqr */
    32,	/* eqi */
    32,	/* ger */
    32,	/* gei */
    32,	/* ger_u */
    32,	/* gei_u */
    32,	/* gtr */
    32,	/* gti */
    32,	/* gtr_u */
    32,	/* gti_u */
    32,	/* ner */
    32,	/* nei */
    16,	/* movr */
    16,	/* movi */
    16,	/* movnr */
    16,	/* movzr */
    16,	/* extr_c */
    16,	/* extr_uc */
    16,	/* extr_s */
    16,	/* extr_us */
    16,	/* extr_i */
    16,	/* extr_ui */
    32,	/* htonr_us */
    32,	/* htonr_ui */
    16,	/* htonr_ul */
    16,	/* ldr_c */
    32,	/* ldi_c */
    16,	/* ldr_uc */
    32,	/* ldi_uc */
    16,	/* ldr_s */
    32,	/* ldi_s */
    16,	/* ldr_us */
    32,	/* ldi_us */
    16,	/* ldr_i */
    32,	/* ldi_i */
    16,	/* ldr_ui */
    32,	/* ldi_ui */
    16,	/* ldr_l */
    32,	/* ldi_l */
    32,	/* ldxr_c */
    48,	/* ldxi_c */
    16,	/* ldxr_uc */
    32,	/* ldxi_uc */
    32,	/* ldxr_s */
    48,	/* ldxi_s */
    16,	/* ldxr_us */
    32,	/* ldxi_us */
    32,	/* ldxr_i */
    48,	/* ldxi_i */
    16,	/* ldxr_ui */
    32,	/* ldxi_ui */
    16,	/* ldxr_l */
    32,	/* ldxi_l */
    16,	/* str_c */
    32,	/* sti_c */
    16,	/* str_s */
    32,	/* sti_s */
    16,	/* str_i */
    32,	/* sti_i */
    16,	/* str_l */
    32,	/* sti_l */
    16,	/* stxr_c */
    32,	/* stxi_c */
    16,	/* stxr_s */
    32,	/* stxi_s */
    16,	/* stxr_i */
    32,	/* stxi_i */
    16,	/* stxr_l */
    32,	/* stxi_l */
    32,	/* bltr */
    32,	/* blti */
    32,	/* bltr_u */
    32,	/* blti_u */
    32,	/* bler */
    32,	/* blei */
    32,	/* bler_u */
    32,	/* blei_u */
    32,	/* beqr */
    48,	/* beqi */
    32,	/* bger */
    32,	/* bgei */
    32,	/* bger_u */
    32,	/* bgei_u */
    32,	/* bgtr */
    32,	/* bgti */
    32,	/* bgtr_u */
    32,	/* bgti_u */
    32,	/* bner */
    48,	/* bnei */
    32,	/* bmsr */
    48,	/* bmsi */
    32,	/* bmcr */
    48,	/* bmci */
    96,	/* boaddr */
    112,	/* boaddi */
    64,	/* boaddr_u */
    64,	/* boaddi_u */
    96,	/* bxaddr */
    112,	/* bxaddi */
    64,	/* bxaddr_u */
    64,	/* bxaddi_u */
    112,	/* bosubr */
    112,	/* bosubi */
    64,	/* bosubr_u */
    64,	/* bosubi_u */
    112,	/* bxsubr */
    112,	/* bxsubi */
    64,	/* bxsubr_u */
    64,	/* bxsubi_u */
    16,	/* jmpr */
    16,	/* jmpi */
    32,	/* callr */
    48,	/* calli */
    0,	/* prepare */
    0,	/* pushargr */
    0,	/* pushargi */
    0,	/* finishr */
    0,	/* finishi */
    0,	/* ret */
    0,	/* retr */
    0,	/* reti */
    0,	/* retval_c */
    0,	/* retval_uc */
    0,	/* retval_s */
    0,	/* retval_us */
    0,	/* retval_i */
    0,	/* retval_ui */
    0,	/* retval_l */
    128,	/* epilog */
    0,	/* arg_f */
    0,	/* getarg_f */
    0,	/* putargr_f */
    0,	/* putargi_f */
    16,	/* addr_f */
    48,	/* addi_f */
    16,	/* subr_f */
    48,	/* subi_f */
    48,	/* rsbi_f */
    16,	/* mulr_f */
    48,	/* muli_f */
    160,	/* divr_f */
    192,	/* divi_f */
    16,	/* negr_f */
    16,	/* absr_f */
    80,	/* sqrtr_f */
    32,	/* ltr_f */
    64,	/* lti_f */
    32,	/* ler_f */
    64,	/* lei_f */
    32,	/* eqr_f */
    64,	/* eqi_f */
    32,	/* ger_f */
    64,	/* gei_f */
    32,	/* gtr_f */
    64,	/* gti_f */
    32,	/* ner_f */
    64,	/* nei_f */
    32,	/* unltr_f */
    64,	/* unlti_f */
    32,	/* unler_f */
    64,	/* unlei_f */
    48,	/* uneqr_f */
    96,	/* uneqi_f */
    32,	/* unger_f */
    64,	/* ungei_f */
    32,	/* ungtr_f */
    64,	/* ungti_f */
    48,	/* ltgtr_f */
    96,	/* ltgti_f */
    32,	/* ordr_f */
    64,	/* ordi_f */
    32,	/* unordr_f */
    64,	/* unordi_f */
    32,	/* truncr_f_i */
    32,	/* truncr_f_l */
    48,	/* extr_f */
    16,	/* extr_d_f */
    16,	/* movr_f */
    32,	/* movi_f */
    16,	/* ldr_f */
    32,	/* ldi_f */
    16,	/* ldxr_f */
    32,	/* ldxi_f */
    16,	/* str_f */
    32,	/* sti_f */
    16,	/* stxr_f */
    32,	/* stxi_f */
    32,	/* bltr_f */
    64,	/* blti_f */
    32,	/* bler_f */
    64,	/* blei_f */
    32,	/* beqr_f */
    64,	/* beqi_f */
    32,	/* bger_f */
    64,	/* bgei_f */
    32,	/* bgtr_f */
    64,	/* bgti_f */
    32,	/* bner_f */
    64,	/* bnei_f */
    32,	/* bunltr_f */
    64,	/* bunlti_f */
    32,	/* bunler_f */
    64,	/* bunlei_f */
    80,	/* buneqr_f */
    112,	/* buneqi_f */
    32,	/* bunger_f */
    64,	/* bungei_f */
    32,	/* bungtr_f */
    64,	/* bungti_f */
    80,	/* bltgtr_f */
    112,	/* bltgti_f */
    32,	/* bordr_f */
    64,	/* bordi_f */
    32,	/* bunordr_f */
    64,	/* bunordi_f */
    0,	/* pushargr_f */
    0,	/* pushargi_f */
    0,	/* retr_f */
    0,	/* reti_f */
    0,	/* retval_f */
    0,	/* arg_d */
    0,	/* getarg_d */
    0,	/* putargr_d */
    0,	/* putargi_d */
    16,	/* addr_d */
    48,	/* addi_d */
    16,	/* subr_d */
    48,	/* subi_d */
    48,	/* rsbi_d */
    16,	/* mulr_d */
    48,	/* muli_d */
    160,	/* divr_d */
    192,	/* divi_d */
    16,	/* negr_d */
    16,	/* absr_d */
    80,	/* sqrtr_d */
    32,	/* ltr_d */
    64,	/* lti_d */
    32,	/* ler_d */
    64,	/* lei_d */
    32,	/* eqr_d */
    64,	/* eqi_d */
    32,	/* ger_d */
    64,	/* gei_d */
    32,	/* gtr_d */
    64,	/* gti_d */
    32,	/* ner_d */
    64,	/* nei_d */
    32,	/* unltr_d */
    64,	/* unlti_d */
    32,	/* unler_d */
    64,	/* unlei_d */
    48,	/* uneqr_d */
    96,	/* uneqi_d */
    32,	/* unger_d */
    64,	/* ungei_d */
    32,	/* ungtr_d */
    64,	/* ungti_d */
    48,	/* ltgtr_d */
    96,	/* ltgti_d */
    32,	/* ordr_d */
    64,	/* ordi_d */
    32,	/* unordr_d */
    64,	/* unordi_d */
    32,	/* truncr_d_i */
    32,	/* truncr_d_l */
    48,	/* extr_d */
    16,	/* extr_f_d */
    16,	/* movr_d */
    32,	/* movi_d */
    16,	/* ldr_d */
    32,	/* ldi_d */
    16,	/* ldxr_d */
    32,	/* ldxi_d */
    16,	/* str_d */
    32,	/* sti_d */
    16,	/* stxr_d */
    32,	/* stxi_d */
    32,	/* bltr_d */
    64,	/* blti_d */
    32,	/* bler_d */
    64,	/* blei_d */
    32,	/* beqr_d */
    64,	/* beqi_d */
    32,	/* bger_d */
    64,	/* bgei_d */
    32,	/* bgtr_d */
    64,	/* bgti_d */
    32,	/* bner_d */
    64,	/* bnei_d */
    32,	/* bunltr_d */
    64,	/* bunlti_d */
    32,	/* bunler_d */
    64,	/* bunlei_d */
    80,	/* buneqr_d */
    112,	/* buneqi_d */
    32,	/* bunger_d */
    64,	/* bungei_d */
    32,	/* bungtr_d */
    64,	/* bungti_d */
    80,	/* bltgtr_d */
    112,	/* bltgti_d */
    32,	/* bordr_d */
    64,	/* bordi_d */
    32,	/* bunordr_d */
    64,	/* bunordi_d */
    0,	/* pushargr_d */
    0,	/* pushargi_d */
    0,	/* retr_d */
    0,	/* reti_d */
    0,	/* retval_d */
    0,	/* movr_w_f */
    0,	/* movr_ww_d */
    0,	/* movr_w_d */
    0,	/* movr_f_w */
    0,	/* movi_f_w */
    0,	/* movr_d_ww */
    0,	/* movi_d_ww */
    16,	/* movr_d_w */
    32,	/* movi_d_w */
    32,	/* bswapr_us */
    32,	/* bswapr_ui */
    16,	/* bswapr_ul */
    48,	/* casr */
    64,	/* casi */
#endif /* __WORDSIZE */
